Description
Run the run_all() method for all defined steps of a stage for which the
check() method returns TRUE.
Usage
run_stage(name, stages = load_from_file())
Arguments
name
[string]
The name of the stage to run.
stages
[named list]
A named list of Stage objects as returned by load_from_file(),
by default loaded from tic.R.